<?php
/**
* anoFile - Ajax file upload
* 
* @version 1.0
* @author Angel Kostadinov 
* @copyright Anowave
*/
class anoFile
{
	
	const ERROR_UNKNOWN_EXT = 'The file extension is not allowed';
	const ERROR_MAX_SIZE 	= 'The file exceeds the maximum file size allowed';
	const ERROR_FAIL		= 'Failed to upload file';
	
	private $errors = array();
	private $files  = array();
	
	/**
	* @var (object) Instance of anoFile
	*/
	static $instance = null;
	
	/**
	* @var (array) List of allowed extensions
	*/
	private $allow = array
	(
		'png',
		'jpg',
		'gif',
		'bmp',
		'pdf'
	);
	
	private $max_size = 1000;
		
	/**
	* File upload
	*/
	public function upload()
	{
		if ($_FILES)
		{
			$files = array();
		
			foreach ($_FILES['upload']['name'] as $index => $value)
			{
				$files[] = array
				(
					'name' 		=> $_FILES['upload']['name'][$index],
					'size' 		=> $_FILES['upload']['size'][$index],
					'type' 		=> $_FILES['upload']['type'][$index],
					'tmp_name' 	=> $_FILES['upload']['tmp_name'][$index],
					'error' 	=> $_FILES['upload']['error'][$index]
				);
			}

			foreach ($files as $file)
			{
				list($dirname, $basename, $extension, $filename) = array_values
				(
					pathinfo($file['name'])
				);
				
				if (in_array(strtolower($extension), $this->allow))
				{
					if (move_uploaded_file($file['tmp_name'], "tmp/{$file['name']}"))
					{
						$this->files[] = array_merge($file, array
						(
							'size' => $this->format($file['size']),
							'name' => $file['name']
						));
					}
					else 
					{
						$this->errors[] = self::ERROR_FAIL;
					}
				}
				else 
				{
					$this->errors[] = self::ERROR_UNKNOWN_EXT;
				}
			}
		}
		
		return $this;
	}
	
	public function getResponse()
	{
		header('Content-Type: application/json');
		
		echo json_encode(array
		(
			'success' 	=> (!$this->errors) ? true : false,
			'files' 	=> $this->files,
			'errors' 	=> $this->errors
		));
		exit();
	}
	
	/**
	* Format price into human readable format
	* 
	* @param (int) Size in bytes
	* @param (int) Precision
	*/
	private function format($size, $precision = 2)
	{
		$S = 'BkMGTPEZY';
	    $F = floor((strlen($size) - 1)/3);
	    
	    return sprintf("%.{$precision}f", $size/pow(1024, $F)).' '. @$S[$F] .'B';
	}

	
	/**
	* Get instance
	*/
	static function getInstance()
	{
		if (null === self::$instance)
		{
			self::$instance = new self();
		}
		
		return self::$instance;
	}
	
	final private function __construct(){}
	final private function __clone(){}
}

anoFile::getInstance()->upload()->getResponse();